"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MarkdownEditorComponent = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const browser_1 = require("@opensumi/ide-editor/lib/browser");
const common_1 = require("../common");
const MarkdownEditorComponent = ({ resource }) => {
    let container = null;
    const markdownService = (0, ide_core_browser_1.useInjectable)(common_1.IMarkdownService);
    const documentService = (0, ide_core_browser_1.useInjectable)(browser_1.IEditorDocumentModelService);
    react_1.default.useEffect(() => {
        if (container) {
            const disposer = new ide_core_browser_1.Disposable();
            const cancellation = new ide_core_browser_1.CancellationTokenSource();
            disposer.addDispose({
                dispose: () => {
                    cancellation.cancel();
                },
            });
            documentService.createModelReference(resource.uri, 'markdown-preview').then((documentRef) => {
                if (cancellation.token.isCancellationRequested) {
                    if (documentRef) {
                        documentRef.dispose();
                    }
                    return;
                }
                const onUpdate = new ide_core_browser_1.Emitter();
                disposer.addDispose(onUpdate);
                disposer.addDispose(documentRef.instance.getMonacoModel().onDidChangeContent((e) => {
                    onUpdate.fire(documentRef.instance.getText());
                }));
                if (container) {
                    // container可能已不存在
                    markdownService
                        .previewMarkdownInContainer(documentRef.instance.getText(), container, cancellation.token, undefined, onUpdate.event)
                        .then((r) => {
                        disposer.addDispose(r);
                    });
                }
                disposer.addDispose(documentRef);
            });
            return () => {
                disposer.dispose();
            };
        }
    });
    return (react_1.default.createElement("div", { ref: (el) => {
            container = el;
        }, style: { height: '100%' } }));
};
exports.MarkdownEditorComponent = MarkdownEditorComponent;
//# sourceMappingURL=editor.markdown.js.map