"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MarkdownServiceImpl = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const utils_1 = require("@opensumi/ide-components/lib/utils");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const http_opener_1 = require("@opensumi/ide-core-browser/lib/opener/http-opener");
const ide_webview_1 = require("@opensumi/ide-webview");
const mardown_style_1 = require("./mardown.style");
let MarkdownServiceImpl = class MarkdownServiceImpl {
    // 检测下支持的协议，以防打开内部协议
    isSupportedLink(uri) {
        return http_opener_1.HttpOpener.standardSupportedLinkSchemes.has(uri.scheme);
    }
    async previewMarkdownInContainer(content, container, cancellationToken, options, onUpdate, onLinkClick) {
        const body = await this.getBody(content, options);
        if (cancellationToken.isCancellationRequested) {
            return new ide_core_browser_1.Disposable();
        }
        const disposer = new ide_core_browser_1.Disposable();
        const webviewElement = this.webviewService.createWebview({
            enableFindWidget: true,
            localResourceRoots: [],
        });
        webviewElement.appendTo(container);
        webviewElement.setContent(body);
        disposer.addDispose(webviewElement.onDidClickLink((link) => {
            if (!link) {
                return;
            }
            // Whitelist supported schemes for links
            if (this.isSupportedLink(link)) {
                this.openerService.open(link);
            }
            if (onLinkClick) {
                onLinkClick(link);
            }
        }));
        disposer.addDispose(webviewElement);
        if (onUpdate) {
            disposer.addDispose(onUpdate(async (content) => {
                const body = await this.getBody(content, options);
                if (!cancellationToken.isCancellationRequested) {
                    webviewElement.setContent(body);
                }
            }));
        }
        return disposer;
    }
    async getBody(content, options) {
        return new Promise((resolve, reject) => {
            (0, utils_1.parseMarkdown)(content, options, (err, result) => {
                if (err) {
                    reject(err);
                }
                resolve(removeEmbeddedSVGs(renderBody(result)));
            });
        });
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_webview_1.IWebviewService),
    tslib_1.__metadata("design:type", Object)
], MarkdownServiceImpl.prototype, "webviewService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.IOpenerService),
    tslib_1.__metadata("design:type", Object)
], MarkdownServiceImpl.prototype, "openerService", void 0);
MarkdownServiceImpl = tslib_1.__decorate([
    (0, di_1.Injectable)()
], MarkdownServiceImpl);
exports.MarkdownServiceImpl = MarkdownServiceImpl;
function renderBody(body) {
    return `<!DOCTYPE html>
    <html>
      <head>
        <meta http-equiv="Content-type" content="text/html;charset=UTF-8">
        <meta http-equiv="Content-Security-Policy" content="default-src 'none'; img-src http: https: data:; media-src https:; script-src 'none'; style-src 'unsafe-inline'; child-src 'none'; frame-src 'none';">
        <style>
          ${mardown_style_1.markdownCss}
        </style>
      </head>
      <body>
        <a id="scroll-to-top" role="button" aria-label="scroll to top" href="#"><span class="icon"></span></a>
        ${body}
      </body>
    </html>`;
}
function removeEmbeddedSVGs(documentContent) {
    const newDocument = new DOMParser().parseFromString(documentContent, 'text/html');
    // remove all inline svgs
    const allSVGs = newDocument.documentElement.querySelectorAll('svg');
    if (allSVGs) {
        // eslint-disable-next-line @typescript-eslint/prefer-for-of
        for (let i = 0; i < allSVGs.length; i++) {
            const svg = allSVGs[i];
            if (svg.parentNode) {
                svg.parentNode.removeChild(allSVGs[i]);
            }
        }
    }
    return newDocument.documentElement.outerHTML;
}
//# sourceMappingURL=markdown.service.js.map